const { chromium } = require('playwright');
const path = require('path');
const fs = require('fs').promises;

/**
 * 基础爬虫类
 * 提供所有爬虫共用的基础功能
 */
class BaseCrawler {
  constructor(config) {
    this.config = config;
    this.browser = null;
    this.context = null;
    this.page = null;
  }

  /**
   * 初始化浏览器
   * @returns {Promise<void>}
   */
  async initBrowser() {
    this.browser = await chromium.launch({ 
      headless: true,
      args: ['--no-sandbox', '--disable-setuid-sandbox']
    });
    this.context = await this.browser.newContext({ 
      locale: 'ja-JP',
      userAgent: 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36'
    });
    this.page = await this.context.newPage();
  }

  /**
   * 关闭浏览器
   * @returns {Promise<void>}
   */
  async closeBrowser() {
    if (this.browser) {
      await this.browser.close();
      this.browser = null;
      this.context = null;
      this.page = null;
    }
  }

  /**
   * 创建截图目录
   * @returns {Promise<string>} 截图目录路径
   */
  async createScreenshotDir() {
    const dir = path.join(process.cwd(), 'screenshots');
    await fs.mkdir(dir, { recursive: true });
    return dir;
  }

  /**
   * 获取商品信息
   * @param {string} url - 商品URL
   * @returns {Promise<Object>} 商品信息
   */
  async crawl(url) {
    throw new Error('Method not implemented');
  }

  /**
   * 解析价格
   * @param {string} priceText - 价格文本
   * @returns {Promise<number>} 解析后的价格
   */
  async parsePrice(priceText) {
    throw new Error('Method not implemented');
  }

  /**
   * 处理优惠券
   * @returns {Promise<number>} 优惠券金额
   */
  async handleCoupon() {
    throw new Error('Method not implemented');
  }

  /**
   * 获取商品标题
   * @returns {Promise<string>} 商品标题
   */
  async getTitle() {
    throw new Error('Method not implemented');
  }

  /**
   * 获取商品SKU
   * @returns {Promise<string>} 商品SKU
   */
  async getSku() {
    throw new Error('Method not implemented');
  }

  /**
   * 获取商品变体信息
   * @returns {Promise<Array>} 变体信息数组
   */
  async getVariants() {
    throw new Error('Method not implemented');
  }
}

module.exports = BaseCrawler; 